package it.arquillian.moduleTest.jpa.controller;

import it.arquillian.moduleTest.jpa.ArchiveFactory;
import it.arquillian.moduleTest.jpa.entity.Action;
import it.arquillian.moduleTest.jpa.exceptions.PreexistingEntityException;
import it.arquillian.moduleTest.jpa.exceptions.RollbackFailureException;
import it.arquillian.moduleTest.jpa.util.ManageExceptionStackTrace;
import java.util.ArrayList;
import java.util.List;
import javax.ejb.EJB;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.persistence.*;
import static org.junit.Assert.*;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.slf4j.LoggerFactory;
import org.slf4j.Logger;

/**
 * Test ActionJpaController EJB
 *
 * @author Marco!Cella
 */
@RunWith(Arquillian.class)
public class ActionJpaControllerTest extends ArchiveFactory {
    @EJB
    private ActionJpaController actionJpaController;
    
    private static String className = ActionJpaControllerTest.class.getName();
    
    final Logger logger = LoggerFactory.getLogger(ActionJpaControllerTest.class);
    
    @Test
//    @Cleanup(phase = TestExecutionPhase.NONE)
    @UsingDataSet("jpa/controller/ActionJpaControllerTest/ShouldFindSetOfActionEntities.xml")
    @ShouldMatchDataSet(value = "jpa/controller/ActionJpaControllerTest/ShouldFindSetOfActionEntitiesAssert.xml")
    @Cleanup(phase = TestExecutionPhase.AFTER, strategy = CleanupStrategy.USED_ROWS_ONLY)
    public void shouldFindSetOfActionEntities() throws Exception {
        logger.info("\nExecute test: {} [#] shouldFindSetOfActionEntities", className);
        // given
        int givenMaxResults = 3;
        int givenFirstResult = 2;
        int expectedActionCount = 3;
        List<Action> expectedActionEntities = new ArrayList<Action>();
        for(int i=3; i<=5; i++){
            expectedActionEntities.add( new Action( Integer.valueOf(i) ) );
        }
        // when
        List<Action> actionEntities = actionJpaController.findActionEntities( givenMaxResults, givenFirstResult );
        // then
        assertNotNull( "Action entities list must not be null:\n", actionEntities );
        assertEquals( "Wrong Action entities count:\n", expectedActionCount, actionEntities.size() );
        assertEquals( "Wrong Action entities list:\n", expectedActionEntities, actionEntities );
    }
    
}
